@@ -11,7 +11,7 @@ from rich.logging import RichHandler
 
 from griffon.output import console
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 
 if "CORGI_API_URL" not in os.environ:
     print("Must set CORGI_API_URL environment variable.")
@@ -52,6 +52,18 @@ def get_config():
 griffon_config = get_config()
 
 
+def get_config_option(section, option, default_value=None):
+    if griffon_config.has_option(section, option):
+        return griffon_config.get(section, option)
+    if default_value:
+        return default_value
+    return None
+
+
+def list_config_sections():
+    return griffon_config.sections()
+
+
 class CorgiService:
     name = "component-registry"
     description = "Red Hat component registry"
