@@ -79,6 +79,12 @@ def component_type_style(type):
     return f"[{color}]{type}[/{color}]"
 
 
+def output_version(ctx, version):
+    if version.startswith("sha256") and ctx.obj["SHORT_VERSION_VALUES"]:
+        return f"sha256 ...{version[-8:]}"
+    return version
+
+
 def text_output_product_summary(ctx, output, format, exclude_products):
     ordered_results = sorted(output["results"], key=lambda d: d["name"])
 
@@ -236,7 +242,9 @@ def text_output_products_contain_component(ctx, output, format, exclude_products
                         root_component = "root component"
                         if sources:
                             source_purl = PackageURL.from_string(sources[0]["purl"])
-                            root_component = f"{source_purl.name}-{source_purl.version}"
+                            root_component = (
+                                f"{source_purl.name}-{output_version(ctx,source_purl.version)}"
+                            )
 
                         dep_name = name.replace(component_name, f"[b]{component_name}[/b]")
                         dep = f"[white]({dep_name}, {item['type'].lower()})[/white]"
@@ -274,7 +282,9 @@ def text_output_products_contain_component(ctx, output, format, exclude_products
                         root_component = "root component"
                         if sources:
                             source_purl = PackageURL.from_string(sources[0]["purl"])
-                            root_component = f"{source_purl.name}-{source_purl.version}"
+                            root_component = (
+                                f"{source_purl.name}-{output_version(ctx,source_purl.version)}"
+                            )
                         dep_name = nvr.replace(component_name, f"[b]{component_name}[/b]")
                         dep = f"[white]({dep_name}, {item['type'].lower()})[/white]"
                         related_url = related_url.replace(
@@ -314,7 +324,9 @@ def text_output_products_contain_component(ctx, output, format, exclude_products
                         root_component = "root component"
                         if sources:
                             source_purl = PackageURL.from_string(sources[0]["purl"])
-                            root_component = f"{source_purl.name}-{source_purl.version}"
+                            root_component = (
+                                f"{source_purl.name}-{output_version(ctx,source_purl.version)}"
+                            )
                         upstream = ""
                         if item["upstream_purl"]:
                             upstream = f"[cyan]{item['upstream_purl']}[/cyan]"
@@ -638,11 +650,11 @@ def cprint(
     show_count: bool = True,
 ):
     """handle format and output"""
-    from griffon import griffon_config
+    from griffon import get_config_option
 
     exclude_products = None
-    if ctx.obj["PROFILE"] != "all":
-        exclude_products = griffon_config.get(ctx.obj["PROFILE"], "exclude").split("\n")
+    if ctx.obj["PROFILE"] != "default":
+        exclude_products = get_config_option(ctx.obj["PROFILE"], "exclude").split("\n")
 
     output = raw_json_transform(data, show_count)
     if ctx and ctx.obj["NO_COLOR"]:
